@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2016 Mirai Solutions GmbH
+# Copyright (C) 2010-2017 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ wrapList <- function(x) {
 	if(!is(x, "list")) x <- list(x)
 	# Extract 'jobj' slot for S4 classes (such as 'workbook' & 'cellstyle')
 	x <- lapply(x, function(y) {
-		if(!is(y, "jobjRef") && "jobj" %in% slotNames(y)) y@jobj
+		if(!is(y, "jobjRef") && .hasSlot(y, "jobj")) y@jobj
 		else y
 	})
 	x
