@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2013 Mirai Solutions GmbH
+# Copyright (C) 2010-2017 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ test.workbook.writeAndReadWorksheet <- function() {
 		createSheet(wb, worksheet)
 		writeWorksheet(wb, df, worksheet, startRow = startRow, startCol = startCol)
 		res <- readWorksheet(wb, worksheet, startRow = startRow, startCol = startCol,
-				endRow = -1, endCol = -1)	
+				endRow = 0, endCol = 0)	
 		checkEquals(normalizeDataframe(df), res, check.attributes = FALSE, check.names = TRUE)
 	}
 	
